==> gbsite-1.0.0.tar.gz: gbsite/htdocs/admin/updatepage.php <==
<?
    require_once("config.php");

    $conn  = pg_pconnect("host=$DBHOST port=$DBPORT user=$DBUSER dbname=$DBNAME password=$DBPASS");

    if($action == "delete") {
        $query = "delete from page_info ".
                 " where http_host = '$w_siteid' ".
                 "   and web_page  = '$pageid' ";
        $res   = pg_exec($conn,$query);
        include("./showsite.php");
        exit();
    } else if($action == "update") {
        $query = "update page_info ".
                 "   set page_title = '$page_title', ".
                 "       page_template = '$page_template', ".
                 "       page_header = '$page_header', ".
                 "       meta_description = '$meta_description', ".
                 "       meta_keyword = '$meta_keyword', ".
                 "       group_id = '$group_id', ".
                 "       link_name = '$link_name', ".
                 "       page_url = '$page_url', ".
                 "       active = $active, ".
                 "       order_number = $order_number ".
                 " where http_host = '$w_siteid' ".
                 "   and web_page = '$pageid' ";
        $res   = pg_exec($conn,$query);
    } else if($action == "new") {
        $query = "insert into page_info ".
                 "       (http_host,web_page,page_title,page_template, ".
                 "        link_name,page_url) ".
                 "values ('$w_siteid','$pageid','$page_title','$page_template', ".
                 "        '$page_title','/$pageid.php') ";
        $res   = pg_exec($conn,$query);
    }

    include("./showpage.php");

 ?>

==> gbsite-1.1.1.tar.gz: gbsite/htdocs/admin/updatepage.php <==
<?
    require_once("config.php");

    $conn  = pg_pconnect("host=$DBHOST port=$DBPORT user=$DBUSER dbname=$DBNAME password=$DBPASS");

    if($action == "delete") {
        $query = "delete from page_info ".
                 " where http_host = '$w_siteid' ".
                 "   and web_page  = '$pageid' ";
        $res   = pg_exec($conn,$query);
        include("./showsite.php");
        exit();
    } else if($action == "update") {
        if($group_id == "\\N") $group_id = null;
        else                   $group_id = "'" . $group_id . "'";
        $query = "update page_info ".
                 "   set page_title = '$page_title', ".
                 "       page_template = '$page_template', ".
                 "       page_header = '$page_header', ".
                 "       meta_description = '$meta_description', ".
                 "       meta_keyword = '$meta_keyword', ".
                 "       group_id = $group_id, ".
                 "       link_name = '$link_name', ".
                 "       page_url = '$page_url', ".
                 "       active = $active, ".
                 "       use_master = $use_master, ".
                 "       order_number = $order_number ".
                 " where http_host = '$w_siteid' ".
                 "   and web_page = '$pageid' ";
        $res   = pg_exec($conn,$query);
    } else if($action == "new") {
        $query = "insert into page_info ".
                 "       (http_host,web_page,page_title,page_template, ".
                 "        link_name,page_url) ".
                 "values ('$w_siteid','$pageid','$page_title','$page_template', ".
                 "        '$page_title','/$pageid.php') ";
        $res   = pg_exec($conn,$query);
    }

    include("./showpage.php");

 ?>
